@@ -549,7 +549,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.8',
  'LIBDIR': '/usr/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/lib/libffi-3.2.1/include',
+ 'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
